# THIS FILE IS AUTOMATICALLY GENERATED, DO NOT EDIT MANUALLY.

from enum import Enum

class SkeletonTypus(Enum): ...
class SkeletonInstructionBaseItem: ...
class SkeletonInstructionItem(SkeletonInstructionBaseItem): ...
class DirSkeletonReader: ...



#!/usr/bin/env python
# setup.py generated by flit for tools that don't yet use PEP 517

from distutils.core import setup

packages = \
['gidlogger', 'gidlogger.utility', 'gidlogger.utility.stubs']

package_data = \
{'': ['*']}

setup(name='gidlogger',
      version='0.1.9',
      description='custom logging function from Giddi',
      author='Giddius',
      author_email=None,
      url=None,
      packages=packages,
      package_data=package_data,
     )
